package jain.application.services.jcp;

/*
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Copyrights:
 *
 *  Copyright - 2001 Sun Microsystems, Inc. All rights reserved.
 *  901 San Antonio Road, Palo Alto, California 94043, U.S.A.
 *
 *  This product and related documentation are protected by copyright and
 *  distributed under licenses restricting its use, copying, distribution, and
 *  decompilation. No part of this product or related documentation may be
 *  reproduced in any form by any means without prior written authorization of
 *  Sun and its licensors, if any.
 *
 *  RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the United
 *  States Government is subject to the restrictions set forth in DFARS
 *  252.227-7013 (c)(1)(ii) and FAR 52.227-19.
 *
 *  The product described in this manual may be protected by one or more U.S.
 *  patents, foreign patents, or pending applications.
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  Author:
 *
 *  Telcordia Technologies, Inc.
 *  Farooq Anjum, John-Luc Bakker, Ravi Jain
 *  445 South Street
 *  Morristown, NJ 07960
 *
 *  Version       : 1.0
 *  Notes         :
 *
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */

/**
    This interface reports all changes to the Call object.
 * The {@link JcpCallEvent} interface is the base interface for
 * all Call-related events.
 * All Call-related events must extend this interface.
 * Events which extend this interface are reported via the
 * <CODE>JcpCallListener</CODE> interface.
 *
 * <p>
 * An individual <CODE>JcpCallEvent</CODE> conveys one of a series of different
 * possible Call state changes;
 * the specific Call state change is indicated by
 * the {@link JcpEvent#getID()}
 * value returned by the event.
 *
 * <p>
 * The {@link JcpConnectionListener}
 * interface extends this
 * interface. This reflects the fact that all Connection 
 * events can be reported via the <CODE>JcpCallListener</CODE> interface.
 *
 * <p>
 * The {@link JcpCallEvent#getCall()} method on this interface returns the
 * Call
 * associated with the Call event.
 */
public interface JcpCallListener extends java.util.EventListener
{
    /**
        Indicates that the state of the {@link JcpCall} object has changed to {@link JcpCall#ACTIVE}.
        <br>

        @param callevent JcpCallEvent with eventID {@link JcpCallEvent#CALL_ACTIVE}.
    */
    public void callActive( JcpCallEvent callevent );

    /**
        Indicates that the state of the {@link JcpCall} object has changed to {@link JcpCall#INVALID}.
        <br>

        @param callevent JcpCallEvent with eventID {@link JcpCallEvent#CALL_INVALID}.
    */
    public void callInvalid( JcpCallEvent callevent );


    /**
        This method is called to indicate that the application will no longer receive 
        JcpCallEvent events on the instance of the JcpCallListener.
        <br>

        @param callevent JcpCallEvent with eventID {@link JcpCallEvent#CALL_EVENT_TRANSMISSION_ENDED}.
    */
    public void callEventTransmissionEnded( JcpCallEvent callevent );
    /**
        Indicates that the state of the JcpCall object has changed to {@link JcpCall#IDLE}.
        <br>

        @param callevent JcpCallEvent with eventID {@link JcpCallEvent#CALL_CREATED}.
    */
    public void callCreated( JcpCallEvent callevent );

    
}

